Class: RDoc::ClassModule

Inherits:
Object
  • Object
show all
Defined in:
lib/rorvswild_theme_rdoc/patches/rdoc_before_6.8.0.rb

Instance Method Summary collapse

Instance Method Details

#super_classesObject

Get all super classes of this class in an array. The last element might be a string if the name is unknown.



6
7
8
9
10
11
12
13
14
# File 'lib/rorvswild_theme_rdoc/patches/rdoc_before_6.8.0.rb', line 6

def super_classes
  result = []
  parent = self
  while parent = parent.superclass
    result << parent
    return result if parent.is_a?(String)
  end
  result
end